@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ from tencentcloud.ssl.v20191205 import models
 class SslClient(AbstractClient):
     _apiVersion = '2019-12-05'
     _endpoint = 'ssl.tencentcloudapi.com'
+    _service = 'ssl'
 
 
     def ApplyCertificate(self, request):
@@ -138,7 +139,7 @@ class SslClient(AbstractClient):
 
 
     def CompleteCertificate(self, request):
-        """本接口（CompleteCertificate）用于主动触发证书验证。
+        """本接口（CompleteCertificate）用于主动触发证书验证。仅非DNSPod和Wotrus品牌证书支持使用此接口。
 
         :param request: Request instance for CompleteCertificate.
         :type request: :class:`tencentcloud.ssl.v20191205.models.CompleteCertificateRequest`
@@ -165,6 +166,34 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateCertificate(self, request):
+        """本接口（CreateCertificate）用于创建付费证书。
+
+        :param request: Request instance for CreateCertificate.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CreateCertificateRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CreateCertificateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateCertificate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateCertificateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteCertificate(self, request):
         """本接口（DeleteCertificate）用于删除证书。
 
@@ -193,6 +222,34 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteManager(self, request):
+        """删除管理人
+
+        :param request: Request instance for DeleteManager.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DeleteManagerRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DeleteManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteManager", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCertificate(self, request):
         """本接口（DescribeCertificate）用于获取证书信息。
 
@@ -305,6 +362,90 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDeployedResources(self, request):
+        """证书查询关联资源
+
+        :param request: Request instance for DescribeDeployedResources.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeDeployedResourcesRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeDeployedResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDeployedResources", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDeployedResourcesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeManagerDetail(self, request):
+        """查询管理人详情
+
+        :param request: Request instance for DescribeManagerDetail.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeManagerDetailRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeManagerDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeManagerDetail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeManagerDetailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeManagers(self, request):
+        """查询管理人列表
+
+        :param request: Request instance for DescribeManagers.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeManagersRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeManagersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeManagers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeManagersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DownloadCertificate(self, request):
         """本接口（DownloadCertificate）用于下载证书。
 
@@ -417,8 +558,64 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RevokeCertificate(self, request):
+        """本接口（RevokeCertificate）用于吊销证书。
+
+        :param request: Request instance for RevokeCertificate.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.RevokeCertificateRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.RevokeCertificateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RevokeCertificate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RevokeCertificateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def SubmitAuditManager(self, request):
+        """重新提交审核管理人
+
+        :param request: Request instance for SubmitAuditManager.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.SubmitAuditManagerRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.SubmitAuditManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SubmitAuditManager", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SubmitAuditManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SubmitCertificateInformation(self, request):
-        """提交证书资料。
+        """提交证书资料。输入参数信息可以分多次提交，但提交的证书资料应最低限度保持完整。
 
         :param request: Request instance for SubmitCertificateInformation.
         :type request: :class:`tencentcloud.ssl.v20191205.models.SubmitCertificateInformationRequest`
@@ -466,6 +663,90 @@ class SslClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UploadConfirmLetter(self, request):
+        """本接口（UploadConfirmLetter）用于上传证书确认函。
+
+        :param request: Request instance for UploadConfirmLetter.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.UploadConfirmLetterRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.UploadConfirmLetterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UploadConfirmLetter", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UploadConfirmLetterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UploadRevokeLetter(self, request):
+        """本接口（UploadRevokeLetter）用于上传证书吊销确认函。
+
+        :param request: Request instance for UploadRevokeLetter.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.UploadRevokeLetterRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.UploadRevokeLetterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UploadRevokeLetter", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UploadRevokeLetterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def VerifyManager(self, request):
+        """重新核验管理人
+
+        :param request: Request instance for VerifyManager.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.VerifyManagerRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.VerifyManagerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("VerifyManager", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.VerifyManagerResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
